Changeset: e0fcf3e786d5 for MonetDB
URL: http://dev.monetdb.org/hg/MonetDB?cmd=changeset;node=e0fcf3e786d5
Modified Files:
        
Branch: default
Log Message:

Merged from Dec2011


diffs (78 lines):

diff --git a/monetdb5/modules/mal/Makefile.ag b/monetdb5/modules/mal/Makefile.ag
--- a/monetdb5/modules/mal/Makefile.ag
+++ b/monetdb5/modules/mal/Makefile.ag
@@ -15,7 +15,7 @@
 # Copyright August 2008-2011 MonetDB B.V.
 # All Rights Reserved.
 
-INCLUDES = ../../misc ../../mal ../atoms ../kernel \
+INCLUDES = ../../mal ../atoms ../kernel \
        ../../../clients/mapilib \
        ../../../common/options \
        ../../../common/stream \
diff --git a/tools/merovingian/daemon/merovingian.c 
b/tools/merovingian/daemon/merovingian.c
--- a/tools/merovingian/daemon/merovingian.c
+++ b/tools/merovingian/daemon/merovingian.c
@@ -437,7 +437,7 @@ autoUpgradePassphraseMar2011Apr2011(conf
  * Explicitly pulled out functionality that is just implemented to
  * obtain an automatic upgrade path.
  *
  * Starting from the Jan2012? release, the discoveryport setting has
  * disappeared.  Instead, a boolean discovery is available to enable or
  * disable the service.  It always uses the same port as the connections
  * are on.
@@ -449,7 +449,7 @@ autoUpgradePassphraseMar2011Apr2011(conf
  * took place).
  */
 static char
-autoUpgradeDiscoveryPortAug2011Jan2012(confkeyval *mckv)
+autoUpgradeDiscoveryPortAug2011Dec2011(confkeyval *mckv)
 {
        confkeyval *kv;
        confkeyval ckv[] = {
@@ -478,7 +478,7 @@ autoUpgradeDiscoveryPortAug2011Jan2012(c
  * Explicitly pulled out functionality that is just implemented to
  * obtain an automatic upgrade path.
  *
  * Starting from the Jan2012? release, the controlport setting has
  * disappeared.  Instead, a boolean control is available to enable or
  * disable the (remote) service.  It always uses the same port as the
  * connections are on, since starting from this release the same handler
@@ -493,7 +493,7 @@ autoUpgradeDiscoveryPortAug2011Jan2012(c
  * took place).
  */
 static char
-autoUpgradeControlPortAug2011Jan2012(confkeyval *mckv)
+autoUpgradeControlPortAug2011Dec2011(confkeyval *mckv)
 {
        char *pwhash;
        char hstr[256];
@@ -804,8 +804,8 @@ main(int argc, char *argv[])
                writeProps(_mero_props, ".");
        }
 
-       if (autoUpgradeDiscoveryPortAug2011Jan2012(_mero_props) != 0 ||
-                       autoUpgradeControlPortAug2011Jan2012(_mero_props) != 0)
+       if (autoUpgradeDiscoveryPortAug2011Dec2011(_mero_props) != 0 ||
+                       autoUpgradeControlPortAug2011Dec2011(_mero_props) != 0)
                writeProps(_mero_props, ".");
        /* end upgrades to conf-file in place */
 
@@ -840,12 +840,12 @@ main(int argc, char *argv[])
        if (kv->val != NULL) {
                char *h = kv->val + 1;
                if ((p = strchr(h, '}')) == NULL) {
-                       Mfprintf(stderr, "incompatible passphrase (not hashed), 
"
-                                       MONETDB5_PASSWDHASH);
+                       Mfprintf(stderr, "warning: incompatible passphrase (not 
hashed as "
+                                       MONETDB5_PASSWDHASH "), disabling 
passphrase\n");
                } else {
                        *p = '\0';
                        if (strcmp(h, MONETDB5_PASSWDHASH) != 0) {
-                               Mfprintf(stderr, "passphrase hash '%s' 
incompatible, "
+                               Mfprintf(stderr, "warning: passphrase hash '%s' 
incompatible, "
                                                "expected '%s', disabling 
@@ -437,7 +437,7 @@ autoUpgradePassphraseMar2011Apr2011(conf
  * obtain an automatic upgrade path.
  *
- * Starting from the Jan2012? release, the discoveryport setting has
+ * Starting from the Dec2011 release, the discoveryport setting has
  * disappeared.  Instead, a boolean discovery is available to enable or
  * disable the service.  It always uses the same port as the connections
@@ -478,7 +478,7 @@ autoUpgradeDiscoveryPortAug2011Jan2012(c
  * obtain an automatic upgrade path.
  *
- * Starting from the Jan2012? release, the controlport setting has
+ * Starting from the Dec2011 release, the controlport setting has
  * disappeared.  Instead, a boolean control is available to enable or
  * disable the (remote) service.  It always uses the same port as the
passphrase\n",
                                                h, MONETDB5_PASSWDHASH);
                        } else {
_______________________________________________
Checkin-list mailing list
[email protected]
http://mail.monetdb.org/mailman/listinfo/checkin-list

Reply via email to